@@ -12,10 +12,10 @@ plot.loglm <- function(x,
   residuals <- residuals(x, type = "pearson")
   observed <- residuals * sqrt(expected) + expected
   if(residuals_type == "deviance") residuals <- residuals(x, type = "deviance")
-  
+
   gp <- if(inherits(gp, "grapcon_generator"))
     do.call("gp", c(list(observed, residuals, expected, x$df), as.list(gp_args))) else gp
-  
+
   panel(observed, residuals = residuals, expected = expected, type = type,
     residuals_type = residuals_type, gp = gp, ...)
 }
@@ -29,3 +29,8 @@ assoc.loglm <- function(x, ...)
 {
   plot(x, panel = assoc, ...)
 }
+
+sieve.loglm <- function(x, ...)
+{
+  plot(x, panel = sieve, ...)
+}
